# agecal
This library provides 
1. say "Hi Everyone"
2. Compare age between user and I whether who is younger or older
   - It takes user age as an input.

## Installation
```pip install mickzaa-age```

## How to use it?
```import agecal```
```from agecal import greeting```
```from agecal import compareage```

### To print "Hi everyone"
```greeting.sayHi()``` 

### To compare the age between user and I
```compareage.compare_my_age()``` 

## License
Copyright 2021 Mickzaa